Provides functions for estimating natural direct and indirect effects for mediation analysis. It uses weighting where the weights are functions of estimates of the probability of exposure or treatment assignment (Hong, G (2010). https://cepa.stanford.edu/sites/default/files/workshops/GH_JSM%20Proceedings%202010.pdf Huber, M. (2014). tools:::Rd_expr_doi("10.1002/jae.2341")). Estimation of probabilities can use generalized boosting or logistic regression. Additional functions provide diagnostics of the model fit and weights. The vignette provides details and examples.
Maintainer: Dan McCaffrey dmccaffrey@ets.org
Authors:
Katherine Castellano kecastellano@ets.org
Donna Coffman donna.coffman@temple.edu
Brian Vegetabile bvegetab@rand.org
Megan Schuler mschuler@rand.org
Haoyu Zhou haoyu.zhou@temple.edu